/**
 * @file
 * Average List Items implementation
 *
 * @copyright Copyright © 2012–2020 Magneson.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#include "node.h"
#include "math.h"

VuoModuleMetadata({
                      "title" : "Average List Items",
                      "keywords" : [ "magnitude", "bigger", "smaller", "some", "small", "most", ">", "<", "upper", "range" ],
                      "version" : "2.1.0",
                      "node": {
                          "exampleCompositions" : ["AverageListItems.vuo" ]
                      }
                  });

void nodeEvent
(                                                                                                               //Main setup
        VuoInputData(VuoList_VuoReal) list,                                                                     //Setup an input list
        VuoInputData(VuoInteger, {"default":1,"suggestedMin":1}) averageOfItems,                                //Setup integer input
        VuoOutputData(VuoList_VuoReal) averageList                                                              //Setup the output list
)                                                                                                               //Main setup done

{                                                                                                               //Function start
    unsigned long listCount = VuoListGetCount_VuoReal(list);                                                    //Count the items of the input list
    *averageList = VuoListCreate_VuoReal();                                                                     //Create the output list and point it to the output

    VuoList_VuoReal tempList = VuoListCreateWithCount_VuoReal(averageOfItems, 0.0);                             //Create a list with the size of averageOfItems and set all values to 0.0

    for(int i = 1; i <= listCount; i = i + averageOfItems){                                                     //Create a for loop to process batches the size of averageOfItems
        for(int j = 1; j <= VuoListGetCount_VuoReal(tempList); ++j){                                            //Create a for loop to iterate over the batch size of averageOfItems (the size of the tempList)
            VuoListSetValue_VuoReal(tempList, VuoListGetValue_VuoReal(list, i+ (j - 1)), j, false);             //Set the value for each of the items in the tempList to the corresponding values in the source list
        }
        VuoListAppendValue_VuoReal(*averageList, VuoReal_average(tempList));                                    //Average the values in the tempList and append them to the output list
    }                                                                                                           //For loop done
}                                                                                                               //Function done
