/**
 * @file
 * Change Items In List implementation.
 *
 * @copyright Copyright © 2012–2020 Magneson.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#include "node.h"
#include "VuoLayer.h"

VuoModuleMetadata({
                     "title" : "Change Items in List",
                     "description" : "Changes items in a list by a list of index numbers",
					 "keywords" : [ ],
					 "version" : "1.0.0",
					 "dependencies" : [ ],
					 "node": {
                         "isInterface" : false,
                          "exampleCompositions" : ["ChangeItemsInList.vuo" ]
					 }
				 });

void nodeEvent
(                                                                               //Main setup
        VuoInputData(VuoList_VuoGenericType1) list,                             //Setup an input list for the source to be processed
        VuoInputData(VuoList_VuoInteger) changeItems,                           //Setup an input list pointing to the items to be changed
        VuoInputData(VuoList_VuoGenericType1) newItem,                          //Setup an input list containing new items
        VuoOutputData(VuoList_VuoGenericType1) listOut                          //Setup an output list
)                                                                               //Main setup done

{                                                                               //Function start
    VuoList_VuoGenericType1 changed = VuoListCopy_VuoGenericType1(list);        //Create a copy of the input list named changed
    unsigned long changeCount = VuoListGetCount_VuoInteger(changeItems);        //Count the items to be changed

    for(unsigned long i = 1; i <= changeCount; ++i){                            //Create a for loop iterating over the amount of items to be changed
        VuoListSetValue_VuoGenericType1                                         //Set the value with an index number in a list
                (
                    changed,                                                    //Which list to change an item in
                    VuoListGetValue_VuoGenericType1(newItem, i),                //The value to change to from the newItem list
                    VuoListGetValue_VuoInteger(changeItems, i),                 //The index of the item to change
                    FALSE                                                       //We don't want no - list expansion
                    );
    }                                                                           //For loop done

    *listOut = changed;                                                         //Point the changed list to the output
}                                                                               //Function done

