/**
 * @file
 * Cut Wrapped List implementation
 *
 * @copyright Copyright © 2012–2020 Magneson.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#include "node.h"

VuoModuleMetadata({
                      "title" : "Cut Wrapped List",
                      "keywords" : [ "sort", "indecies", "big", "high", "small", "most", ">", "<", "upper", "limit", "bound", "range" ],
                      "version" : "2.1.0",
                      "genericTypes" : {
                          "VuoGenericType1" : {
                              "defaultType" : "VuoReal",
                              "compatibleTypes" : [ "VuoInteger", "VuoReal", "VuoPoint2d", "VuoPoint3d", "VuoPoint4d", "VuoImage", "VuoLayer" ]
                          }
                      },
                      "node": {
                          "exampleCompositions" : ["CutWrappedList.vuo" ]
                      }
                  });

void nodeEvent
(                                                                                   //Main setup
        VuoInputData(VuoList_VuoGenericType1) list,                                 //Setup an input list
        VuoInputData(VuoInteger, {"default":1,"suggestedMin":1}) startPosition,     //Setup an integer input pointing to a start position
        VuoInputData(VuoInteger, {"default":1,"suggestedMin":1}) itemCount,         //Setup an integer input for the amount of items in the output list
        VuoOutputData(VuoList_VuoGenericType1) partialList                          //Setup the output list
)                                                                                   //Main setup done

{                                                                                   //Function start
    *partialList = VuoListCreate_VuoGenericType1();                                 //Create the output list and point it to the output
    VuoInteger listSize = VuoListGetCount_VuoGenericType1(list);                    //Get the size of the input list

    for(int i = 0; i < itemCount; i++){                                             //Create a for loop iterating over the itemCount size
            VuoGenericType1 value = VuoListGetValue_VuoGenericType1(                //Create a value and set it to a value from a list
                        list,                                                       //The list to get the value from, list
                        (((startPosition - 1) + i) % listSize) + 1                  //The index of the value to get from the list, startPosition corrected for 0-based for-loop, modulo of listSize corrected for 0-based modulo.
                        );

            VuoListAppendValue_VuoGenericType1(*partialList, value);                //Append a value to the output list by pointing to it
        }                                                                           //For loop done
}                                                                                   //Function done
