/**
 * @file
 * Reorder list implementation.
 *
 * @copyright Copyright © 2012–2020 Magneson.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#include "node.h"

VuoModuleMetadata({
                     "title" : "Reorder List",
                     "description" : "Reorders a list by a list of indexes",
					 "keywords" : [ ],
					 "version" : "1.0.0",
					 "dependencies" : [ ],
                      "genericTypes" : {
                          "VuoGenericType1" : {
                              "defaultType" : "VuoReal",
                              "compatibleTypes" : [ "VuoInteger", "VuoReal", "VuoPoint2d", "VuoPoint3d", "VuoPoint4d", "VuoImage", "VuoLayer" ]
                          }
                      },
					 "node": {
                         "isInterface" : false,
                          "exampleCompositions" : ["ReorderList.vuo" ]
					 }
				 });

void nodeEvent
(                                                                           //Main setup
        VuoInputData(VuoList_VuoGenericType1) list,                         //Setup a source list input
        VuoInputData(VuoList_VuoInteger) orderList,                         //Setup an integer list input for the order of the output list
        VuoOutputData(VuoList_VuoGenericType1) listOut                      //Setup of the output list
)                                                                           //Setup done

{                                                                           //Function start
    VuoList_VuoGenericType1 reordered = VuoListCreate_VuoGenericType1();    //Create a list named reordered
    unsigned long orderCount = VuoListGetCount_VuoInteger(orderList);       //Get the length of the New Order list

    for(unsigned long i = 1; i <= orderCount; ++i){                         //Create for loop iterating over the orderList length
        VuoGenericType1 active;                                             //Create variable active
        VuoInteger idx = VuoListGetValue_VuoInteger(orderList, i);          //Create integer variable idx and get the value from the orderList
        active = VuoListGetValue_VuoGenericType1(list, idx);                //Set variable active to a value from the source list at the value from idx
        VuoListAppendValue_VuoGenericType1(reordered, active);              //Append the variable active to the reordered list
    }                                                                       //For loop done

    *listOut = reordered;                                                   //Point the output list to the reordered list
}                                                                           //Function done
